@@ -163,12 +163,12 @@ import six
 
 from openstack import _log
 from openstack._meta import connection as _meta
-from openstack import cloud as _cloud
+from openstack.cloud import openstackcloud as _cloud
 from openstack import config as _config
 from openstack.config import cloud_region
 from openstack import exceptions
 from openstack import service_description
-from openstack import task_manager
+from openstack import task_manager as _task_manager
 
 __all__ = [
     'from_config',
@@ -195,7 +195,7 @@ def from_config(cloud=None, config=None, options=None, **kwargs):
     :param argparse.Namespace options:
         Allows direct passing in of options to be added to the cloud config.
         This does not have to be an actual instance of argparse.Namespace,
-        despite the naming of the the
+        despite the naming of the
         `openstack.config.loader.OpenStackConfig.get_one` argument to which
         it is passed.
 
@@ -212,16 +212,15 @@ def from_config(cloud=None, config=None, options=None, **kwargs):
 
 
 class Connection(six.with_metaclass(_meta.ConnectionMeta,
-                                    _cloud.OpenStackCloud)):
+                                    _cloud._OpenStackCloudMixin)):
 
     def __init__(self, cloud=None, config=None, session=None,
                  app_name=None, app_version=None,
-                 # TODO(shade) Remove these once we've shifted
-                 # python-openstackclient to not use the profile interface.
-                 authenticator=None, profile=None,
                  extra_services=None,
                  strict=False,
                  use_direct_get=False,
+                 task_manager=None,
+                 rate_limit=None,
                  **kwargs):
         """Create a connection to a cloud.
 
@@ -251,18 +250,25 @@ class Connection(six.with_metaclass(_meta.ConnectionMeta,
         :param str app_name: Name of the application to be added to User Agent.
         :param str app_version: Version of the application to be added to
             User Agent.
-        :param authenticator: DEPRECATED. Only exists for short-term backwards
-                              compatibility for python-openstackclient while we
-                              transition. See :doc:`transition_from_profile`
-                              for details.
-        :param profile: DEPRECATED. Only exists for short-term backwards
-                        compatibility for python-openstackclient while we
-                        transition. See :doc:`transition_from_profile`
-                        for details.
         :param extra_services: List of
             :class:`~openstack.service_description.ServiceDescription`
             objects describing services that openstacksdk otherwise does not
             know about.
+        :param bool use_direct_get:
+            For get methods, make specific REST calls for server-side
+            filtering instead of making list calls and filtering client-side.
+            Default false.
+        :param task_manager:
+            Task Manager to handle the execution of remote REST calls.
+            Defaults to None which causes a direct-action Task Manager to be
+            used.
+        :type manager: :class:`~openstack.task_manager.TaskManager`
+        :param rate_limit:
+            Client-side rate limit, expressed in calls per second. The
+            parameter can either be a single float, or it can be a dict with
+            keys as service-type and values as floats expressing the calls
+            per second for that service. Defaults to None, which means no
+            rate-limiting is performed.
         :param kwargs: If a config is not provided, the rest of the parameters
             provided are assumed to be arguments to be passed to the
             CloudRegion contructor.
@@ -274,13 +280,7 @@ class Connection(six.with_metaclass(_meta.ConnectionMeta,
                 self._extra_services[service.service_type] = service
 
         if not self.config:
-            if profile:
-                import openstack.profile
-                # TODO(shade) Remove this once we've shifted
-                # python-openstackclient to not use the profile interface.
-                self.config = openstack.profile._get_config_from_profile(
-                    profile, authenticator, **kwargs)
-            elif session:
+            if session:
                 self.config = cloud_region.from_session(
                     session=session,
                     app_name=app_name, app_version=app_version,
@@ -295,15 +295,23 @@ class Connection(six.with_metaclass(_meta.ConnectionMeta,
                     load_envvars=cloud is not None,
                     **kwargs)
 
-        self.task_manager = task_manager.TaskManager(self.config.full_name)
+        if task_manager:
+            # If a TaskManager was passed in, don't start it, assume it's
+            # under the control of the calling context.
+            self.task_manager = task_manager
+        else:
+            self.task_manager = _task_manager.TaskManager(
+                self.config.full_name,
+                rate=rate_limit)
+            self.task_manager.start()
 
         self._session = None
         self._proxies = {}
         self.use_direct_get = use_direct_get
         self.strict_mode = strict
-        # Call the OpenStackCloud constructor while we work on integrating
-        # things better.
-        _cloud.OpenStackCloud.__init__(self)
+        # Call the _OpenStackCloudMixin constructor while we work on
+        # integrating things better.
+        _cloud._OpenStackCloudMixin.__init__(self)
 
     @property
     def session(self):
@@ -359,3 +367,13 @@ class Connection(six.with_metaclass(_meta.ConnectionMeta,
             return self.session.get_token()
         except keystoneauth1.exceptions.ClientException as e:
             raise exceptions.raise_from_response(e.response)
+
+    def close(self):
+        """Release any resources held open."""
+        self.task_manager.stop()
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self.close()
