@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.network import network_service
 from openstack.network.v2 import tag
 from openstack import resource
 
@@ -19,12 +18,11 @@ class Network(resource.Resource, tag.TagMixin):
     resource_key = 'network'
     resources_key = 'networks'
     base_path = '/networks'
-    service = network_service.NetworkService()
 
     # capabilities
     allow_create = True
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
 
@@ -121,12 +119,11 @@ class DHCPAgentHostingNetwork(Network):
     resources_key = 'networks'
     base_path = '/agents/%(agent_id)s/dhcp-networks'
     resource_name = 'dhcp-network'
-    service = network_service.NetworkService()
 
     # capabilities
     allow_create = False
-    allow_get = True
-    allow_update = False
+    allow_fetch = True
+    allow_commit = False
     allow_delete = False
     allow_list = True
 
