@@ -11,19 +11,17 @@
 # under the License.
 
 from openstack import resource
-from openstack.workflow import workflow_service
 
 
 class Workflow(resource.Resource):
     resource_key = 'workflow'
     resources_key = 'workflows'
     base_path = '/workflows'
-    service = workflow_service.WorkflowService()
 
     # capabilities
     allow_create = True
     allow_list = True
-    allow_get = True
+    allow_fetch = True
     allow_delete = True
 
     _query_mapping = resource.QueryParameters(
